@@ -156,6 +156,7 @@ class Elements(NamedTuple):
             kwargs = {}
         else:
             kwargs = shallow_copy_dict(self.extra_config)
+        update_dict(self.user_defined_config, kwargs)
         # inject fields
         spec = inspect.getfullargspec(type(self)).args[1:-2]
         for key in spec:
@@ -294,8 +295,6 @@ class Elements(NamedTuple):
             }
         if optimizers is not None:
             trainer_config.setdefault("optimizers", optimizers)
-        # inject user defined configs
-        update_dict(self.user_defined_config, kwargs)
         return kwargs
 
     @classmethod
@@ -331,7 +330,7 @@ class Elements(NamedTuple):
         # trainer general
         trainer_config = kwargs.setdefault("trainer_config", {})
         trainer_config.setdefault("update_binary_threshold_at_runtime", False)
-        use_amp = trainer_config.get("use_amp", False)
+        use_amp = kwargs.get("use_amp", False)
         trainer_config["use_amp"] = use_amp and amp is not None
         default_checkpoint_folder = os.path.join(log_folder, "checkpoints")
         trainer_config.setdefault("checkpoint_folder", default_checkpoint_folder)
@@ -390,7 +389,7 @@ class Environment:
                 torch.cuda.set_device(self.local_rank)
 
     def __getattr__(self, item: str) -> Any:
-        return self.config[item]
+        return self.user_defined_config.get(item, self.config[item])
 
     @property
     def user_defined_config(self) -> Dict[str, Any]:
