@@ -11,6 +11,7 @@ from torch import Tensor
 from typing import Any
 from typing import Dict
 from typing import List
+from typing import Type
 from typing import Tuple
 from typing import Union
 from typing import Callable
@@ -18,6 +19,7 @@ from typing import Optional
 from typing import NamedTuple
 from torch.nn import Module
 from torch.nn import ModuleList
+from cftool.misc import register_core
 from cftool.misc import shallow_copy_dict
 from cftool.misc import LoggingMixin
 from cfdata.types import np_int_type
@@ -1070,6 +1072,9 @@ class AttentionOutput(NamedTuple):
     weights: Tensor
 
 
+attentions: Dict[str, Type["Attention"]] = {}
+
+
 class Attention(Module):
     def __init__(
         self,
@@ -1152,11 +1157,19 @@ class Attention(Module):
         tensor = tensor.view(batch_size, seq_len, self.num_heads, self.head_dim)
         return tensor.permute(0, 2, 1, 3).contiguous().view(-1, seq_len, self.head_dim)
 
+    def _get_weights(self, raw_weights: Tensor) -> Tensor:
+        # in most cases the softmax version is good enough
+        return F.softmax(raw_weights, dim=-1)
+
+    def _weights_callback(self, weights: Tensor) -> Tensor:
+        return weights
+
     def forward(
         self,
         q: Tensor,
         k: Tensor,
         v: Tensor,
+        *,
         mask: Optional[Tensor] = None,
     ) -> AttentionOutput:
         # `mask` represents slots which will be zeroed
@@ -1183,9 +1196,10 @@ class Attention(Module):
         if mask is not None:
             raw_weights.masked_fill_(mask, float("-inf"))
         # B * N_head, Sq, Sk -> # B * N_head, Sq, Sk
-        weights = F.softmax(raw_weights, dim=-1)
+        weights = self._get_weights(raw_weights)
         if 0.0 < self.dropout < 1.0:
             weights = F.dropout(weights, self.dropout, self.training)
+        weights = self._weights_callback(weights)
         # B * N_head, Sq, D_head
         output = torch.bmm(weights, v)
         # B * N_head, Sq, D_head -> B, N_head, Sq, D_head
@@ -1198,6 +1212,18 @@ class Attention(Module):
         output = self.activation(self.out_linear(output))
         return AttentionOutput(output, weights.view(-1, self.num_heads, q_len, k_len))
 
+    @classmethod
+    def get(cls, name: str) -> Type["Attention"]:
+        return attentions[name]
+
+    @classmethod
+    def register(cls, name: str) -> Callable[[Type], Type]:
+        global attentions
+        return register_core(name, attentions)
+
+
+Attention.register("basic")(Attention)
+
 
 __all__ = [
     "Linear",
