@@ -6,6 +6,7 @@ import pprint
 import logging
 
 import numpy as np
+import datatable as dt
 import torch.nn as nn
 
 from abc import abstractmethod
@@ -63,7 +64,6 @@ class DataProtocol(ABC):
     is_ts: bool
     is_clf: bool
     is_simplify: bool
-    raw_dim: int
     num_classes: int
 
     raw: DataTuple
@@ -75,6 +75,8 @@ class DataProtocol(ABC):
     _verbose_level: int
     _has_column_names: bool
 
+    __identifier__: str
+
     @abstractmethod
     def __init__(self, **kwargs: Any):
         self._verbose_level = kwargs.get("verbose_level", 2)
@@ -89,7 +91,7 @@ class DataProtocol(ABC):
         file_path: str,
         *,
         contains_labels: bool = True,
-    ) -> Tuple[str_data_type, Optional[str_data_type]]:
+    ) -> Tuple[dt.Frame, Optional[dt.Frame]]:
         pass
 
     @abstractmethod
@@ -484,9 +486,13 @@ class TrainerState:
     def should_extend_epoch(self) -> bool:
         return self.epoch == self.num_epoch and self.epoch < self.max_epoch
 
+    @property
+    def reached_min_epoch(self) -> bool:
+        return self.epoch > self.min_epoch
+
     @property
     def reached_max_epoch(self) -> bool:
-        return self.epoch == self.max_epoch
+        return self.epoch > self.max_epoch
 
     @property
     def disable_logging(self) -> context_error_handler:
